@@ -625,8 +625,8 @@ int createAndBindSocket(const int             family,
 #else
    if((protocol == IPPROTO_MPTCP) || (protocol == IPPROTO_TCP)) {
       const int cmtOnOff = (protocol == IPPROTO_MPTCP);
-      if(ext_setsockopt(sd, IPPROTO_TCP, TCP_MULTIPATH_ENABLE, &cmtOnOff, sizeof(cmtOnOff)) < 0) {
-         if(ext_setsockopt(sd, IPPROTO_TCP, TCP_MULTIPATH_ENABLE_LEGACY, &cmtOnOff, sizeof(cmtOnOff)) < 0) {   // FIXME: get rid of legacy option number!
+      if(ext_setsockopt(sd, IPPROTO_TCP, MPTCP_ENABLED_LEGACY, &cmtOnOff, sizeof(cmtOnOff)) < 0) {
+         if(ext_setsockopt(sd, IPPROTO_TCP, MPTCP_ENABLED, &cmtOnOff, sizeof(cmtOnOff)) < 0) {
             if(protocol == IPPROTO_MPTCP) {
                return(-2);
             }
