@@ -46,16 +46,18 @@
 #define IPPROTO_MPTCP IPPROTO_EGP
 
 /* FIXME: This is ugly, but currently the only way to easily get the #defines for Linux MPTCP! */
-#define TCP_MULTIPATH_DEBUG         10001   /* MPTCP DEBUG on/off  */
-#define TCP_MULTIPATH_ENABLE        42      /* MPTCP ENABLE on/off */
-#define TCP_MULTIPATH_ENABLE_LEGACY 10002
-#define TCP_MULTIPATH_ADD           10003
-#define TCP_MULTIPATH_REMOVE        10004
-#define TCP_MULTIPATH_SUBFLOWS      10005
-#define TCP_MULTIPATH_CONNID        10006
-#define TCP_MULTIPATH_NDIFFPORTS    10007   /* MPTCP NDIFFPORTS  */
-#define TCP_MULTIPATH_PATHMANAGER   10008   /* MPTCP PATHMANAGER */
-#define TCP_MULTIPATH_SCHEDULER     10009   /* MPTCP SCHEDULER   */
+#define MPTCP_ENABLED               42
+#define MPTCP_SCHEDULER             43
+#define MPTCP_PATH_MANAGER          44
+#define MPTCP_INFO                  45
+#define MPTCP_DEBUG                 46
+#define MPTCP_NDIFFPORTS            47
+
+#define MPTCP_ENABLED_LEGACY        10002
+#define MPTCP_SCHEDULER_LEGACY      10009
+#define MPTCP_PATH_MANAGER_LEGACY   10008
+#define MPTCP_DEBUG_LEGACY          10001
+#define MPTCP_NDIFFPORTS_LEGACY     10007
 
 
 /* DCCP definitions */
